@@ -14,10 +14,9 @@ import inspect
 
 from searchStruct import Ui_Search_Structure
 
-# IMPORTANT: we need to keep the module hierarchy, otherwise the book register/singleton is dead
-from haystack import model 
-
+from .. import model
 from .. import signature
+from .. import utils
 
 class SearchStructDialog(QtGui.QDialog, Ui_Search_Structure):
 
@@ -82,10 +81,11 @@ class SearchStructDialog(QtGui.QDialog, Ui_Search_Structure):
     return 
   
   def search_regexp(self):
+    # -> search_regexp(self, regexp, searchName, color=QtCore.Qt.black):
     log.debug('Looking for a regexp r"%s" '%(self.lineEdit_regexp.text()) )
     tab = self.parent().currentTab()
     if tab is not None:
-      items = tab.search_regexp(str(self.lineEdit_regexp.text()))
+      items = tab.search_regexp(str(self.lineEdit_regexp.text()), str(self.lineEdit_regexp.text())[-20:])
       log.debug('The tab has found %d instances'%(len(items)))
     pass
     
@@ -136,7 +136,7 @@ class SearchStructDialog(QtGui.QDialog, Ui_Search_Structure):
       it = None
       for cls,typ in inspect.getmembers(mod, inspect.isclass):
         fullname = '.'.join([mod.__name__,cls])      
-        if typ.__module__.startswith(mod.__name__) and model.isStructType(typ()):
+        if typ.__module__.startswith(mod.__name__) and utils.isStructType(typ()):
           it = QtGui.QTreeWidgetItem(root, [cls] )
           it.setFont(0,font)
           self.classes.add(fullname)
